package jalview.util;

import java.io.IOException;
import java.util.Scanner;

/**
 * This class contains the brain of the analyser program, and contains a number
 * of commands for the processing of data.
 * 
 * @author TZVanaalten
 *
 */

public class ProbabilityAnalyserKickstarter
{

  public static void main(String[] args)
          throws IOException, InterruptedException
  {

    // this does all of the processing
    HMMProbabilityDistributionAnalyser analyser = new HMMProbabilityDistributionAnalyser();

    boolean running = true;
    System.out.println("ACTIVATED");
    while (running)
    {
      Scanner keyboard = new Scanner(System.in);
      String command = keyboard.nextLine();

      Scanner inputScanner = new Scanner(command);
      // prints family to console. Syntax is printFam <index>
      if (command.indexOf("printFam") > -1)
      {
        inputScanner.next();
        int index = inputScanner.nextInt();
        analyser.printFam(index);
        continue;
      }
      // prints HMM to console. Syntax is printHMM <index>
      if (command.indexOf("printHMM") > -1)
      {

        inputScanner.next();
        int index = inputScanner.nextInt();
        analyser.printHMM(index);
        continue;
      }
      // prints family to file in current folder. Syntax is exportFam <index>.
      if (command.indexOf("exportFam") > -1)
      {

        inputScanner.next();
        int index = inputScanner.nextInt();
        String location = inputScanner.next();
        analyser.printFamToFile(index);
        continue;
      }
      // prints HMM to file in current folder. Syntax is exportHMM <index>.
      if (command.indexOf("exportHMM") > -1)
      {

        inputScanner.next();
        int index = inputScanner.nextInt();
        String location = inputScanner.next();
        analyser.printHMMToFile(index);
        continue;
      }
      // Processes data. Syntax is run <number of loops> <increments>. The
      // number loops specifies the number of increments the program will run.
      // After each increment, the data stored currently in the program is
      // exported and re-read back into the program. This is to ensure that the
      // program can be terminated without losing a large quantity of data. The
      // increment is the number of families read per 'save'.
      if (command.indexOf("run") > -1)
      {
        inputScanner.next();

        int loops = inputScanner.nextInt();
        int increments = inputScanner.nextInt();

        for (int i = 0; i < loops; i++)
        {
          analyser.run(increments);
        }
        continue;
      }
      // terminates program. Syntax is terminate.
      if (command.indexOf("terminate") > -1)
      {
        running = false;
        continue;
      }
      // clears files in current directory (Only a specific set of files).
      // Syntax is clear.
      if (command.indexOf("clear") > -1)
      {
        analyser.clear();
        continue;
      }
      // changes current directory. Syntax is cd <directory>
      if (command.indexOf("cd") > -1)
      {
        inputScanner.next();
        analyser.setFolder(inputScanner.next());
      }
      inputScanner.close();
      continue;
    }




  }

}
